@@ -2,7 +2,7 @@
 ## ablrtest
 ##
 ablrtest <- function(z, H, A, r){
-    if(!(class(z)=="ca.jo")){
+    if(!inherits(z , "ca.jo")){
       stop("\nPlease, provide object of class 'ca.jo' as 'z'.\n")
     }
     r <- as.integer(r)
